@@ -3,6 +3,7 @@
 #include <wx/dir.h>
 #include <wx/regex.h>
 #include <iconv.h>
+#include <ctype.h>
 
 static void   toLower(char* string);
 static char*  decode(const char* string);
@@ -461,6 +462,8 @@ WikiData::WikiData(wxString* dataDir, wxString* inFileName)
 		}
 	}
 	fclose(fp);
+
+	isWriteToFile = true;
 }
 
 WikiData::WikiData(wxString* dataDir) {
@@ -520,6 +523,8 @@ WikiData::WikiData(wxString* dataDir) {
 	text    = new wxString(buf, conv);
 
 	if(fp) fclose(fp);
+
+	isWriteToFile = false;
 }
 
 WikiData::~WikiData()
@@ -625,8 +630,11 @@ const wxString* WikiData::getText()
 		MN_FATAL_ERROR(wxT("failed iconv_open"));
 	}
 
-	if(text) {
-		iconv_close(codeSet);
+	if(text && isWriteToFile == true) {
+		delete text;
+		text = NULL;
+	}
+	else if(text && isWriteToFile == false) {
 		return text;
 	}
 
@@ -638,9 +646,6 @@ const wxString* WikiData::getText()
 	}
 
 	while(fgets(buf, MAX_BUF_SIZE, fp)) {
-#ifdef __WXMAC__
-		for(int i = 0; buf[i] != 0; i++) if(buf[i] == (char)MAC_BACKSLASH) buf[i] = '\\';
-#endif
 		inbufPtr = buf;
 		inbufSize = sizeof(buf);
 		outbufPtr = outbuf;
@@ -681,13 +686,19 @@ void WikiData::save()
 	char fullPath[MAX_BUF_SIZE];
 	FILE* fp;
 	iconv_t     codeSet;
-	char        inbuf[MAX_WIKI_TEXT_SIZE];
-	char        outbuf[MAX_WIKI_TEXT_SIZE];
-	const char*       inbufPtr;
+	char*        inbuf;
+	char*        outbuf;
+	const char*  inbufPtr;
 	char*       outbufPtr;
 	int         inbufSize;
 	int         outbufSize;
 
+	inbuf  = (char*)malloc(MAX_WIKI_TEXT_SIZE);
+	outbuf = (char*)malloc(MAX_WIKI_TEXT_SIZE);
+	if(inbuf == NULL || outbuf == NULL) {
+		MN_FATAL_ERROR(wxT("It's too big data. Max size is 5MB."));
+	}
+
 	codeSet = iconv_open(CODE_SET_EUC_JP, CODE_SET_SYSTEM);
 	if(codeSet == (iconv_t)-1) {
 		MN_FATAL_ERROR(wxT("failed iconv_open"));
@@ -699,25 +710,30 @@ void WikiData::save()
 		MN_FATAL_ERROR(wxT("File open error."));
 	}
 
-	memset(inbuf, 0, sizeof(inbuf));
+	memset(inbuf, 0, MAX_WIKI_TEXT_SIZE);
 	strcpy(inbuf,(const char*)text->mb_str());
 
-#ifdef __WXMAC__
-	for(int i = 0; inbuf[i] != 0; i++) if(inbuf[i] == (char)MAC_BACKSLASH) inbuf[i] = '\\';
-#endif
+//#ifdef __WXMAC__
+//	for(int i = 0; inbuf[i] != 0; i++) if(inbuf[i] == (char)MAC_BACKSLASH) inbuf[i] = '\\';
+//#endif
 
 	inbufPtr = inbuf;
 	inbufSize = strlen(inbufPtr);
 	outbufPtr = outbuf;
-	outbufSize = sizeof(outbuf);
+	outbufSize = MAX_WIKI_TEXT_SIZE;
 	memset(outbuf, 0, outbufSize);
 	iconv(codeSet, (ICONV_CONST char**)&inbufPtr, (size_t*)&inbufSize, &outbufPtr, (size_t*)&outbufSize);
 	if(inbufSize != 0) { // iconv error
 		wxMessageBox(wxT("Fail to save, because this memo include KISHU-IZON-MOJI.\nPlease remove KISHU-IZON-MOJI, and try again"), wxT("Fail to save"), wxOK|wxICON_WARNING);
 	}
-	fwrite(outbuf, sizeof(outbuf)-outbufSize, 1, fp);
+	fwrite(outbuf, MAX_WIKI_TEXT_SIZE-outbufSize, 1, fp);
 	fclose(fp);
 	iconv_close(codeSet);
+	
+	free(inbuf);
+	free(outbuf);
+	
+	isWriteToFile = true;
 }
 
 /******* Tools ************************/
