@@ -311,7 +311,7 @@ void mnNotePanelController::handleOpenDocsDir(wxCommandEvent &event)
 	wxExecute(cmd);
 
 	/* open docs directory */
-	openDoc(docDir);
+	openDir(docDir);
 }
 
 void mnNotePanelController::openUrl(wxString& url)
@@ -323,15 +323,15 @@ void mnNotePanelController::openUrl(wxString& url)
 #endif
 
 #ifdef __WXMAC__
-	cmd.sprintf(wxT("open %s"), url.c_str());
+	cmd.sprintf(wxT("open \'%s\'"), url.c_str());
 #endif
 
 #ifdef __WXCOCOA__
-	cmd.sprintf(wxT("open %s"), url.c_str());
+	cmd.sprintf(wxT("open \'%s\'"), url.c_str());
 #endif
 
 #ifdef __WXGTK__
-	cmd.sprintf(wxT("gnome-open %s"), url.c_str());
+	cmd.sprintf(wxT("gnome-open \'%s\'"), url.c_str());
 #endif
 
 	//wxExecute(argv);
@@ -343,21 +343,47 @@ void mnNotePanelController::openDoc(wxString& doc)
 	wxString cmd;
 
 #ifdef __WXMSW__
-	cmd.sprintf(wxT("cmd /c \"start %s\""), doc.c_str());
+#include <windows.h>
+	ShellExecute(NULL, wxT("OPEN"), doc.c_str(), NULL, NULL, SW_SHOWNORMAL);
+	return;
 #endif
 
 #ifdef __WXMAC__
-	cmd.sprintf(wxT("open %s"), doc.c_str());
+	cmd.sprintf(wxT("open \'%s\'"), doc.c_str());
 #endif
 
 #ifdef __WXCOCOA__
-	cmd.sprintf(wxT("open %s"), doc.c_str());
+	cmd.sprintf(wxT("open \'%s\'"), doc.c_str());
 #endif
 
 #ifdef __WXGTK__
-	cmd.sprintf(wxT("gnome-open %s"), doc.c_str());
+	cmd.sprintf(wxT("gnome-open \'%s\'"), doc.c_str());
 #endif
 
 	wxExecute(cmd);
 }
 
+void mnNotePanelController::openDir(wxString& dir)
+{
+	wxString cmd;
+
+#ifdef __WXMSW__
+	cmd.sprintf(wxT("explorer \"%s\""), dir.c_str());
+#endif
+
+#ifdef __WXMAC__
+	cmd.sprintf(wxT("open \'%s\'"), dir.c_str());
+#endif
+
+#ifdef __WXCOCOA__
+	cmd.sprintf(wxT("open \'%s\'"), dir.c_str());
+#endif
+
+#ifdef __WXGTK__
+	cmd.sprintf(wxT("gnome-open \'%s\'"), dir.c_str());
+#endif
+
+	wxExecute(cmd);
+}
+
+
